Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(582)

Unified Diff: third_party/WebKit/Source/core/layout/ng/ng_positioned_float.h

Issue 2850893003: Add container_block_offset,top_offset to NGFloatingObject. (Closed)
Patch Set: add-inline-to-block-flow-with-block-children-that-do-not-need-anonymous-boxes.html is still broken Created 3 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « third_party/WebKit/Source/core/layout/ng/ng_fragment_builder.cc ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: third_party/WebKit/Source/core/layout/ng/ng_positioned_float.h
diff --git a/third_party/WebKit/Source/core/layout/ng/ng_positioned_float.h b/third_party/WebKit/Source/core/layout/ng/ng_positioned_float.h
index 8443fa0746a60bcad997ae98c663004f8015e4dd..affb8030b1027f191b922fabfd3432a41491833d 100644
--- a/third_party/WebKit/Source/core/layout/ng/ng_positioned_float.h
+++ b/third_party/WebKit/Source/core/layout/ng/ng_positioned_float.h
@@ -13,21 +13,23 @@ namespace blink {
// Contains the information necessary for copying back data to a FloatingObject.
struct CORE_EXPORT NGPositionedFloat {
NGPositionedFloat(RefPtr<NGPhysicalFragment> fragment,
- NGLogicalOffset offset,
- LayoutUnit left_offset)
- : fragment(fragment), offset(offset), left_offset(left_offset) {}
+ const NGLogicalOffset& logical_offset,
+ const NGPhysicalOffset& paint_offset)
+ : fragment(fragment),
+ logical_offset(logical_offset),
+ paint_offset(paint_offset) {}
RefPtr<NGPhysicalFragment> fragment;
- NGLogicalOffset offset;
+ NGLogicalOffset logical_offset;
// In the case where a legacy FloatingObject is attached to not its own
// parent, e.g. a float surrounded by a bunch of nested empty divs,
// NG float fragment's LeftOffset() cannot be used as legacy FloatingObject's
// left offset because that offset should be relative to the original float
// parent.
// {@code left_offset} is calculated when we know to which parent this float
// would be attached.
- LayoutUnit left_offset;
+ NGPhysicalOffset paint_offset;
};
} // namespace blink
« no previous file with comments | « third_party/WebKit/Source/core/layout/ng/ng_fragment_builder.cc ('k') | no next file » | no next file with comments »
@@ -13,21 +13,23 @@ namespace blink {
// left offset because that offset should be relative to the original float
// parent.
- // {@code left_offset} is calculated when we know to which parent this float
+ // {@code paint_offset} is calculated when we know to which parent this float
// would be attached.

Powered by Google App Engine
This is Rietveld 408576698